TkfCrash class

Constructors

TkfCrash({required String title, required String msg, required String buttonText})

Properties

buttonText String
final
hashCode int
The hash code for this object.
no setterinherited
msg String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

builder(Widget? widget, {String? title, String? subtitle, String? buttonText, TextStyle? titleStyle, TextStyle? subtitleStyle, bool isDev = false, Function? beforeExit}) Widget
dev(List<String> st, FlutterErrorDetails errorDetails) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release(List<String> st, FlutterErrorDetails errorDetails) Widget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited