TkfIcons class

Constructors

TkfIcons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

path String
no setter

Static Methods

arrowLeft({double? width, double? height, Color? color}) Widget
arrowRight({double? width, double? height, Color? color}) Widget
close({double? width, double? height, Color? color}) Widget
edit({double? width, double? height, Color? color}) Widget
emptySearch({double? width, double? height, Color? color}) Widget
eye({double? width, double? height, required Color color}) Widget
failed({double? width, double? height, Color? color, BoxFit boxFit = BoxFit.contain}) Widget
success({double? width, double? height, Color? color, BoxFit boxFit = BoxFit.contain}) Widget
svgWidget({required String svgPath, double? width, double? height, ColorFilter? colorFilter}) Widget
toFar({double? width, double? height, Color? color}) Widget