TkfPopups class

Constructors

TkfPopups()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

expiredPopup({required BuildContext context, Function? beforePopup, required String title, required String msg, required String buttonTestKey, required String buttonName, required dynamic onButton()}) Future<void>
showGrpcPopup({required BuildContext context, required String defaultErrMsg, required GrpcError grpcErr, required String buttonTestKey, required String buttonName, required dynamic onButton(), String? err, String? noConnectionMsg, Function? beforePopup}) Future<void>
Basing on parameters shows popup with grpc error message
showPopup({required bool isError, required BuildContext context, required Function onClose, required String buttonTestKey, required String buttonName, Function? beforePopup, String? title, String? msg}) → void