TkfQrScanner class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TkfQrScanner
Constructors
- TkfQrScanner({Key? key, required Function onWillPop, required Function setScannerFrame, required dynamic onPayload(Barcode barcode), required Color borderColor, Color appBarColor = kAppBarBackground, required String title, required TextStyle titleStyle, required String textUnderScanner, required TextStyle textUnderScannerStyle, required String noQrText, String noQrKey = "noQr", dynamic onNoQr()?, required bool showNoQr, required bool isLoading, required MobileScannerController controller, TextStyle? noQrStyle, int? errorMaxLines, double safeAreaOffset = 0})
-
const
Properties
- appBarColor → Color
-
final
- borderColor → Color
-
final
- controller → MobileScannerController
-
final
- errorMaxLines → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- noQrKey → String
-
final
- noQrStyle → TextStyle?
-
final
- noQrText → String
-
final
- onNoQr → dynamic Function()?
-
final
- onPayload → dynamic Function(Barcode barcode)
-
final
- onWillPop → Function
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safeAreaOffset → double
-
final
- scanSize → double
-
final
- setScannerFrame → Function
-
final
- showNoQr → bool
-
final
- textUnderScanner → String
-
final
- textUnderScannerStyle → TextStyle
-
final
- title → String
-
final
- titleStyle → TextStyle
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited