TkfSearchAppBar class

Inheritance

Constructors

TkfSearchAppBar({Key? key, Color appBarColor = kAppBarBackground, required dynamic onBackButton(), required Color backIconColor, required String titleText, required TextStyle titleStyle, required String hint, required String searchKey, required String buttonKey, required TextEditingController ctr, required dynamic onChanged(String), TextStyle? hintStyle})
const

Properties

appBarColor Color
final
backIconColor Color
final
buttonKey String
final
ctr TextEditingController
final
hashCode int
The hash code for this object.
no setterinherited
hint String
final
hintStyle TextStyle?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onBackButton → dynamic Function()
final
onChanged → dynamic Function(String)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchKey String
final
titleStyle TextStyle
final
titleText String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited